"use client"

import { useState, useEffect, useRef } from "react"
import { CircularProgressbar, buildStyles } from "react-circular-progressbar"
import "react-circular-progressbar/dist/styles.css"

type TimerProps = {
  duration: number
  onTimeUp: () => void
  isActive: boolean
}

export default function Timer({ duration, onTimeUp, isActive }: TimerProps) {
  const [timeLeft, setTimeLeft] = useState(duration)
  const onTimeUpRef = useRef(onTimeUp)

  // Mettre à jour la référence quand onTimeUp change
  useEffect(() => {
    onTimeUpRef.current = onTimeUp
  }, [onTimeUp])

  useEffect(() => {
    if (!isActive) return

    const timer = setInterval(() => {
      setTimeLeft((prevTime) => {
        if (prevTime <= 1) {
          clearInterval(timer)
          // Utiliser la référence pour éviter les problèmes de fermeture
          setTimeout(() => {
            onTimeUpRef.current()
          }, 0)
          return 0
        }
        return prevTime - 1
      })
    }, 1000)

    return () => clearInterval(timer)
  }, [isActive, duration])

  useEffect(() => {
    if (isActive) {
      setTimeLeft(duration)
    }
  }, [isActive, duration])

  const percentage = (timeLeft / duration) * 100

  // Determine color based on time left
  let pathColor = "#34C759" // Green (route-green)
  if (timeLeft < 10) {
    pathColor = "#FF3B30" // Red (route-red)
  } else if (timeLeft < 20) {
    pathColor = "#FFCC00" // Yellow (route-yellow)
  }

  return (
    <div className="w-12 h-12">
      <CircularProgressbar
        value={percentage}
        text={`${timeLeft}`}
        styles={buildStyles({
          textSize: "32px",
          pathColor,
          textColor: pathColor,
          trailColor: "#F2F2F7",
          pathTransition: "stroke-dashoffset 0.5s ease 0s",
        })}
      />
    </div>
  )
}
